@@ -10,8 +10,9 @@ next_task_to_run <- function(g) {
 #' @importFrom igraph .env
 task_get_lib_loc <- function(g, node, output) {
   nhood <- task_graph_neighborhoods(g, node)[[1]]
-  name <- names(node) %||% node
+  name <- names(node) %||% node # nolint
   nhood <- nhood[names(nhood) != .env$name]
+
   # Custom packages are possible only for the check type nodes which are
   # always terminal. Therefore if we sort nhood making custom packages appear
   # first, their lib will always be prioritized
@@ -40,7 +41,12 @@ start_task <- function(task, g, ...) {
 }
 
 #' @export
-start_task.install_task_spec <- function(task, g, output, lib.loc, ...) {
+start_task.install_task_spec <- function(
+    task,
+    g,
+    output,
+    lib.loc, # nolint object_name_linter
+    ...) {
   spec <- task_graph_task_spec(g, task)
   install_parameters <- install_parameters(spec$package_spec)
   libpaths <- c(task_get_lib_loc(g, task, output), lib.loc)
@@ -58,7 +64,12 @@ start_task.install_task_spec <- function(task, g, output, lib.loc, ...) {
 }
 
 #' @export
-start_task.custom_install_task_spec <- function(task, g, output, lib.loc, ...) {
+start_task.custom_install_task_spec <- function(
+    task,
+    g,
+    output,
+    lib.loc, # nolint object_name_linter
+    ...) {
   spec <- task_graph_task_spec(g, task)
   install_parameters <- install_parameters(spec$package_spec)
   libpaths <- c(task_get_lib_loc(g, task, output), lib.loc)
@@ -76,7 +87,12 @@ start_task.custom_install_task_spec <- function(task, g, output, lib.loc, ...) {
 }
 
 #' @export
-start_task.check_task_spec <- function(task, g, output, lib.loc, ...) {
+start_task.check_task_spec <- function(
+    task,
+    g,
+    output,
+    lib.loc, # nolint object_name_linter
+    ...) {
   spec <- task_graph_task_spec(g, task)
   libpaths <- c(task_get_lib_loc(g, task, output), lib.loc)
   path <- check_path(spec$package_spec, output = path_sources())
